pub fn validate_css(bytes: &[u8]) -> Result<&str, HonzoError>Expand description
Validate CSS bytes by parsing as a stylesheet with cssparser. Returns the CSS as a string slice if valid.
pub fn validate_css(bytes: &[u8]) -> Result<&str, HonzoError>Validate CSS bytes by parsing as a stylesheet with cssparser. Returns the CSS as a string slice if valid.